import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "Solid は、状態の更新に浅いイミュータブルなパターンを使用することを強く推奨します。読み取りと書き込みを分離することで、コンポーネントのレイヤーを通過する際にプロキシの変更を追跡できなくなるリスクなく、システムのリアクティビティをよりよくコントロールできます。これは、Signal に比べてストアの方がより効果的です。"
    }), "\n", jsxs(_components.p, {
      children: ["しかし、ミューテーションの方が推論しやすい場合もあります。そのため、Solid は Immer にインスパイアされた ", jsx(_components.code, {
        children: "produce"
      }), " ストア修飾子を提供しており、", jsx(_components.code, {
        children: "setStore"
      }), " 呼び出し内で Store オブジェクトの書き込み可能なプロキシバージョンを変更できます。"]
    }), "\n", jsxs(_components.p, {
      children: ["これは、制御を放棄せず、小さな範囲での変更を可能にするための素晴らしいツールです。Todo の例でイベントハンドラーのコードを以下のように置き換えて、", jsx(_components.code, {
        children: "produce"
      }), " を使ってみましょう:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "addTodo"
        }), " = (", jsx(_components.span, {
          className: "hljs-params",
          children: "text"
        }), ") => {\n  ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setStore"
        }), "(\n    ", jsx(_components.span, {
          className: "hljs-string",
          children: "'todos'"
        }), ",\n    ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "produce"
        }), "(", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "todos"
          }), ") =>"]
        }), " {\n      todos.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "push"
        }), "({ ", jsx(_components.span, {
          className: "hljs-attr",
          children: "id"
        }), ": ++todoId, text, ", jsx(_components.span, {
          className: "hljs-attr",
          children: "completed"
        }), ": ", jsx(_components.span, {
          className: "hljs-literal",
          children: "false"
        }), " });\n    }),\n  );\n};\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "toggleTodo"
        }), " = (", jsx(_components.span, {
          className: "hljs-params",
          children: "id"
        }), ") => {\n  ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setStore"
        }), "(\n    ", jsx(_components.span, {
          className: "hljs-string",
          children: "'todos'"
        }), ",\n    ", jsxs(_components.span, {
          className: "hljs-function",
          children: [jsx(_components.span, {
            className: "hljs-params",
            children: "todo"
          }), " =>"]
        }), " todo.", jsx(_components.span, {
          className: "hljs-property",
          children: "id"
        }), " === id,\n    ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "produce"
        }), "(", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "todo"
          }), ") =>"]
        }), " (todo.", jsx(_components.span, {
          className: "hljs-property",
          children: "completed"
        }), " = !todo.", jsx(_components.span, {
          className: "hljs-property",
          children: "completed"
        }), ")),\n  );\n};\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["ストアを使った ", jsx(_components.code, {
        children: "produce"
      }), " はおそらく大半のケースに対応していますが、Solid には ", jsx(_components.code, {
        children: "createMutable"
      }), " から利用できる、ミュータブルな Store オブジェクトもあります。内部 API には推奨されない方法ですが、サードパーティシステムとの相互運用や互換性のためには有用な場合があります。"]
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
