import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["JSX では、JavaScript を使ってテンプレート内のロジックフローを制御できます。しかし仮想 DOM がない場合、", jsx(_components.code, {
        children: "Array.prototype.map"
      }), " のようなものを単純に使用すると、更新のたびにすべての DOM ノードを無駄に再作成してしまいます。その代わりに、リアクティブライブラリではテンプレートヘルパーを使用するのが一般的です。Solid では、それらをコンポーネントでラップしています。"]
    }), "\n", jsxs(_components.p, {
      children: ["最も基本的な制御フローは、条件分岐です。Solid のコンパイラは賢く、三項演算子（", jsx(_components.code, {
        children: "a ? b : c"
      }), "）やブーリアンの式（", jsx(_components.code, {
        children: "a && b"
      }), "）を最適に処理します。しかし、多くの場合は Solid の ", jsx(_components.code, {
        children: "<Show>"
      }), " コンポーネントを使用する方が読みやすくになります。"]
    }), "\n", jsx(_components.p, {
      children: "この例では、現在の状態（ユーザーがログインしているかどうか）を反映した適切なボタンだけを表示したいと思います。JSX を次のように更新します:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Show"
        }), "\n  when={", jsx(_components.span, {
          className: "hljs-title function_",
          children: "loggedIn"
        }), "()}\n  fallback={", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{toggle}"
            }), ">"]
          }), "Log in", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "}\n>\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{toggle}"
            }), ">"]
          }), "Log out", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Show"
        }), ">\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["この ", jsx(_components.code, {
        children: "fallback"
      }), " プロパティは ", jsx(_components.code, {
        children: "else"
      }), " の役割を果たし、", jsx(_components.code, {
        children: "when"
      }), " に渡された条件が ", jsx(_components.code, {
        children: "true"
      }), " でない場合に表示されます。"]
    }), "\n", jsx(_components.p, {
      children: "これで、ボタンをクリックすると、期待通り交互に変化します。"
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
