import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "컨텍스트는 Store를 위한 훌륭한 도구입니다. 인젝션을 처리하고, 소유권을 리액티브 그래프에 연결하고, 자동으로 할당 해제를 관리하며, Solid의 세분화된 렌더링 덕분에 렌더링 오버헤드가 없습니다."
    }), "\n", jsxs(_components.p, {
      children: ["때로는 컨텍스트를 사용하는게 너무 과도한 경우가 있으며, 대안은 리액티브 시스템을 직접 사용하는 것입니다.\n예를 들어, 전역 스코프에 시그널을 생성하고 다른 모듈에서 사용할 수 있도록 ", jsx(_components.code, {
        children: "export"
      }), "함으로써 전역 리액티브 데이터 스토어를 구축할 수 있습니다."]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " { createSignal } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// 다른 소스 파일:"
        }), "\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " counter ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'./counter'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = counter;\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Solid의 반응성은 보편적인 개념입니다. 이것이 컴포넌트 내부에 있는지 외부에 있는지는 중요하지 않습니다. 전역 상태 vs 로컬 상태에 대한 별도의 구분된 개념은 없으며, 모두 같은 것입니다."
    }), "\n", jsxs(_components.p, {
      children: ["유일한 제한 사항은 모든 계산(이펙트/메모)이 리액티브 루트(", jsx(_components.code, {
        children: "createRoot"
      }), ") 아래에 생성되어야 한다는 점입니다. Solid의 ", jsx(_components.code, {
        children: "render"
      }), "는 이를 자동으로 수행합니다."]
    }), "\n", jsxs(_components.p, {
      children: ["이 예제에서는 ", jsx(_components.code, {
        children: "counter.tsx"
      }), "가 전역 Store입니다. ", jsx(_components.code, {
        children: "main.tsx"
      }), "의 컴포넌트를 다음과 같이 수정할 수 있습니다:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " { count, doubleCount, increment } = counter;\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "type"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"button\""
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{increment}"
            }), ">"]
          }), "\n    {count()} {doubleCount()}\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "따라서 계산을 포함하는 더 복잡한 전역 Store를 사용할 때는 루트를 생성해야 합니다. 또는 더 나은 방법으로는 컨텍스트를 사용하세요."
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
