import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span",
    a: "a",
    blockquote: "blockquote"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "Сигналы"
      }), " являются краеугольным камнем реактивности Solid. Они содержат значения, которые меняются со временем; когда вы меняете значение ", jsx(_components.code, {
        children: "Сигнала"
      }), ", он автоматически обновляет все, что его использует."]
    }), "\n", jsxs(_components.p, {
      children: ["Чтобы создать ", jsx(_components.code, {
        children: "Сигнал"
      }), ", давайте импортируем ", jsx(_components.code, {
        children: "createSignal"
      }), " из ", jsx(_components.code, {
        children: "solid-js"
      }), " и вызовем его из нашего компонента ", jsx(_components.code, {
        children: "Counter"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Аргумент, переданный ", jsx(_components.code, {
        children: "createSignal"
      }), ", — это начальное значение, а возвращаемое значение — это кортеж (", jsx(_components.code, {
        children: "tuple"
      }), ") с двумя функциями: ", jsx(_components.a, {
        href: "https://developer.mozilla.org/ru/docs/Web/JavaScript/Reference/Functions/get",
        children: "геттером"
      }), " и ", jsx(_components.a, {
        href: "https://developer.mozilla.org/ru/docs/Web/JavaScript/Reference/Functions/set",
        children: "сеттером"
      }), ". С помощью ", jsx(_components.a, {
        href: "https://developer.mozilla.org/ru/docs/Web/JavaScript/Reference/Operators/Destructuring_assignment",
        children: "деструктуризации"
      }), " мы можем называть эти функции как угодно. В этом случае мы называем геттер ", jsx(_components.code, {
        children: "count"
      }), ", а сеттер - ", jsx(_components.code, {
        children: "setCount"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["Важно отметить, что первое возвращаемое значение - это геттер (функция, возвращающая текущее значение), а не само значение. Это потому, что фреймворк должен отслеживать, где этот ", jsx(_components.code, {
        children: "Сигнал"
      }), " считывается, чтобы он мог соответствующим образом всё обновлять."]
    }), "\n", jsxs(_components.p, {
      children: ["В этом уроке мы будем использовать функцию JavaScript ", jsx(_components.code, {
        children: "setInterval"
      }), " для создания периодически увеличивающегося счетчика. Мы можем обновлять наш ", jsx(_components.code, {
        children: "Сигнал"
      }), " ", jsx(_components.code, {
        children: "count"
      }), " каждую секунду, добавив этот код в наш компонент ", jsx(_components.code, {
        children: "Counter"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-built_in",
          children: "setInterval"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setCount"
        }), "(", jsx(_components.span, {
          className: "hljs-title function_",
          children: "count"
        }), "() + ", jsx(_components.span, {
          className: "hljs-number",
          children: "1"
        }), "), ", jsx(_components.span, {
          className: "hljs-number",
          children: "1000"
        }), ");\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Каждый шаг мы читаем предыдущее значение счетчика, прибавляем к нему 1 и устанавливаем новое."
    }), "\n", jsxs(_components.blockquote, {
      children: ["\n", jsxs(_components.p, {
        children: [jsx(_components.code, {
          children: "Сигналы"
        }), " Solid также принимают такую форму функции, в которой вы можете использовать предыдущее значение для установки следующего значения."]
      }), "\n", jsx(_components.pre, {
        children: jsxs(_components.code, {
          className: "hljs language-jsx",
          children: [jsx(_components.span, {
            className: "hljs-title function_",
            children: "setCount"
          }), "(", jsxs(_components.span, {
            className: "hljs-function",
            children: [jsx(_components.span, {
              className: "hljs-params",
              children: "c"
            }), " =>"]
          }), " c + ", jsx(_components.span, {
            className: "hljs-number",
            children: "1"
          }), ");\n"]
        })
      }), "\n"]
    }), "\n", jsxs(_components.p, {
      children: ["Наконец, нам нужно считать ", jsx(_components.code, {
        children: "Сигнал"
      }), " в нашем JSX-коде:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          }), "Count: {count()}", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), ";\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
