import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "Solid のリアクティビティは同期的で、変更の次の行で DOM が更新されることになります。Solid のきめ細かいレンダリングは、リアクティブシステムにおける更新の伝搬にすぎないので、ほとんどの場合、これは完全に問題ありません。関連性のない変更が二度「レンダリング」されても、実際には無駄な作業ではありません。"
    }), "\n", jsxs(_components.p, {
      children: ["もし変更が関連していたらどうでしょうか？　Solid の ", jsx(_components.code, {
        children: "batch"
      }), " ヘルパーは、複数の変更をキューに入れて、オブザーバーに通知する前にすべてを同時に適用できます。バッチ内では、更新された Signal の値は完了するまでコミットされません。"]
    }), "\n", jsxs(_components.p, {
      children: ["この例では、ボタンをクリックしたときに両方の名前を代入していて、レンダリングされた更新を 2 回トリガーしています。ボタンをクリックすると、コンソールにログが表示されます。それでは、", jsx(_components.code, {
        children: "set"
      }), " の呼び出しを batch でラップしましょう。"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [" ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "updateNames"
        }), " = (", jsx(_components.span, {
          className: "hljs-params"
        }), ") => {\n    ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "\"Button Clicked\""
        }), ");\n    ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "batch"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n      ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setFirstName"
        }), "(", jsx(_components.span, {
          className: "hljs-title function_",
          children: "firstName"
        }), "() + ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"n\""
        }), ");\n      ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setLastName"
        }), "(", jsx(_components.span, {
          className: "hljs-title function_",
          children: "lastName"
        }), "() + ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"!\""
        }), ");\n    })\n  }\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "これで完了です。これで、チェンジセット全体に対して一度だけ通知するようになりました。"
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
