import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span",
    a: "a",
    blockquote: "blockquote"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "「Signal」は Solid のリアクティビティの基礎となるものです。これらには、時間とともに変化する値が含まれており、Signal の値を変更すると、それを使用しているすべてのものが自動的に更新されます。"
    }), "\n", jsxs(_components.p, {
      children: ["Signal を作成するには、", jsx(_components.code, {
        children: "solid-js"
      }), " から ", jsx(_components.code, {
        children: "createSignal"
      }), " をインポートして、以下のように Counter コンポーネントから呼び出しましょう:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["create コールに渡される引数は初期値で、戻り値はゲッターとセッターの 2 つの関数を持つ配列です。", jsx(_components.a, {
        href: "https://developer.mozilla.org/ja/docs/Web/JavaScript/Reference/Operators/Destructuring_assignment",
        children: "分割代入"
      }), "によって、これらの関数に好きな名前を付けることができます。この例ではゲッターを ", jsx(_components.code, {
        children: "count"
      }), "、セッターを ", jsx(_components.code, {
        children: "setCount"
      }), " と名付けています。"]
    }), "\n", jsx(_components.p, {
      children: "ここで重要なのは、最初に返される値がゲッター（現在の値を返す関数）であり、値そのものではないということです。これはフレームワークが、Signal がどこで読み取られたかを追跡し、それに応じて物事を更新する必要があるためです。"
    }), "\n", jsxs(_components.p, {
      children: ["このレッスンでは、JavaScript の ", jsx(_components.code, {
        children: "setInterval"
      }), " 関数を使って定期的にインクリメントするカウンターを作成します。以下のコードを Counter コンポーネントに追加することで、1 秒ごとに", jsx(_components.code, {
        children: "count"
      }), " Signal を更新できます:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-built_in",
          children: "setInterval"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setCount"
        }), "(", jsx(_components.span, {
          className: "hljs-title function_",
          children: "count"
        }), "() + ", jsx(_components.span, {
          className: "hljs-number",
          children: "1"
        }), "), ", jsx(_components.span, {
          className: "hljs-number",
          children: "1000"
        }), ");\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "毎回、前回のカウントを読み、1 を加えて、新しい値を設定します。"
    }), "\n", jsxs(_components.blockquote, {
      children: ["\n", jsx(_components.p, {
        children: "Solid の Signal は、前回の値を使って次の値を設定する関数形式も受け付けています。"
      }), "\n", jsx(_components.pre, {
        children: jsxs(_components.code, {
          className: "hljs language-jsx",
          children: [jsx(_components.span, {
            className: "hljs-title function_",
            children: "setCount"
          }), "(", jsxs(_components.span, {
            className: "hljs-function",
            children: [jsx(_components.span, {
              className: "hljs-params",
              children: "c"
            }), " =>"]
          }), " c + ", jsx(_components.span, {
            className: "hljs-number",
            children: "1"
          }), ");\n"]
        })
      }), "\n"]
    }), "\n", jsx(_components.p, {
      children: "最後に、JSX コードで Signal を読み取る必要があります:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          }), "Count: {count()}", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), ";\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
