import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    pre: "pre",
    code: "code",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "Kontext ist ein wunderbares Werkzeug für Stores. Es handhabt das Einfügen der Daten, bindet den Ursprung an den reaktiven Graph, räumt automatisch auf und erzeugt keinen zusätzlichen Render-Aufwand dank Solids feingranularem Rendering."
    }), "\n", jsx(_components.p, {
      children: "Allerdings kann man das reaktive System auch direkt für einfache Dinge einsetzen. Es ist fast nicht der Mühe wert, darauf hinzuweisen, aber ein einfacher schreibbarer Store ist nur ein Signal:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " { createSignal } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// irgendwo anders:"
        }), "\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " counter ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'./counter'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = counter;\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Solids Reaktivität ist ein universelles Konzept. Es spielt keine Rolle, ob sie inner- oder außerhalb von Komponenten läuft. Es gibt kein anderes Konzept für globalen im Gegensatz zu lokalem Zustand. Es ist alles das gleiche."
    }), "\n", jsxs(_components.p, {
      children: ["Die einzige Einschränkung ist, dass alle Berechnungen (Effekte/Memos) in einem reaktiven Root (", jsx(_components.code, {
        children: "createRoot"
      }), ") erzeugt werden müssen. Solids ", jsx(_components.code, {
        children: "render"
      }), " macht das automatisch."]
    }), "\n", jsxs(_components.p, {
      children: ["In dieser Anleitung ist ", jsx(_components.code, {
        children: "counter.tsx"
      }), " solch ein globaler Store. Wir können ihn benutzen, indem wir unsere Komponente in ", jsx(_components.code, {
        children: "mian.tsx"
      }), " umschreiben:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " { count, doubleCount, increment } = counter;\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "type"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"button\""
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{increment}"
            }), ">"]
          }), "\n    {count()} {doubleCount()}\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Wenn wir also unsere eigenen komplizierteren globalen Zustände verwenden, die Berechnungen verwenden, müssen wir einen Root erzeugen - oder wir machen es uns einfach und benutzen stattdessen Context."
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
