import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["Solid предоставляет API ", jsx(_components.code, {
        children: "Контекст"
      }), " (", jsx(_components.code, {
        children: "Context API"
      }), ") для передачи данных не используя props. Это полезно для обмена ", jsx(_components.code, {
        children: "Сигналами"
      }), " и ", jsx(_components.code, {
        children: "Сторами"
      }), ". Преимущество использования ", jsx(_components.code, {
        children: "Контекста"
      }), " заключается в том, что он создается как часть детальной реактивной системы и управляется ею."]
    }), "\n", jsxs(_components.p, {
      children: ["Для начала создадим объект ", jsx(_components.code, {
        children: "Контекста"
      }), ". Этот объект содержит компонент Provider, используемый для ввода наших данных. Однако распространенной практикой является оборачивание компонентов ", jsx(_components.code, {
        children: "Provider"
      }), " и потребителей", jsx(_components.code, {
        children: " useContext"
      }), " со значениями, уже настроенными для конкретного контекста."]
    }), "\n", jsxs(_components.p, {
      children: ["И именно этот подход мы и реализуем в этом примере. Вы можете увидеть определение простого хранилища счетчика в файле ", jsx(_components.code, {
        children: "counter.tsx"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["Чтобы использовать контекст, сначала давайте обернем наш компонент приложения, чтобы мы могли использовать его глобально. Мы будем использовать наш провайдер ", jsx(_components.code, {
        children: "CounterProvider"
      }), ". В этом случае давайте дадим нашему счетчику ему начальное значение 1."]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-title function_",
          children: "render"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "CounterProvider"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "count"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{1}"
            }), ">"]
          }), "\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "App"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "CounterProvider"
            }), ">"]
          })]
        }), "\n), ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "document"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "getElementById"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "\"app\""
        }), "));\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Затем мы можем считать контекст счетчика в нашем компоненте ", jsx(_components.code, {
        children: "nested.tsx"
      }), ". Мы делаем это с помощью потребителя ", jsx(_components.code, {
        children: "useCounter"
      }), "."]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, { increment, decrement }] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useCounter"
        }), "();\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsx(_components.span, {
            className: "hljs-tag",
            children: "<>"
          }), "\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          }), "{count()}", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          }), "\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{increment}"
            }), ">"]
          }), "+", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          }), "\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{decrement}"
            }), ">"]
          }), "-", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          }), "\n  ", jsx(_components.span, {
            className: "hljs-tag",
            children: "</>"
          })]
        }), "\n);\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
