import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "Suspense"
      }), " を使うと、データのロード中にフォールバックコンテンツを表示できます。これは最初のローディングには最適ですが、その後のナビゲーションでは、スケルトン状態にフォールバックすると UX が悪化することがよくあります。"]
    }), "\n", jsxs(_components.p, {
      children: ["そこで、", jsx(_components.code, {
        children: "useTransition"
      }), " を利用することで、フォールバックの状態に戻るのを回避できます。これは、ラッパーと保留中のインジケーターを提供します。ラッパーはすべてのダウンストリームの更新をトランザクションに入れ、すべての非同期イベントが完了するまでコミットしません。"]
    }), "\n", jsxs(_components.p, {
      children: ["つまり、制御フローがサスペンドしている時、現在のブランチを表示し続ける一方で、次のブランチは画面外にレンダリングされるのです。既存の境界の下にある Resource の読み取りは、それをトランジションに追加します。ただし、新しくネストした ", jsx(_components.code, {
        children: "Suspense"
      }), " コンポーネントは、表示される前にロードが完了していない場合には「フォールバック」を表示します。"]
    }), "\n", jsxs(_components.p, {
      children: ["この例では、コンテンツが非表示になってローディングのプレースホルダーに戻ってしまうことが分かります。それでは、", jsx(_components.code, {
        children: "App"
      }), " コンポーネントにトランジションを追加してみましょう。まず、", jsx(_components.code, {
        children: "updateTab"
      }), " 関数を置き換えてみましょう:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [pending, start] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useTransition"
        }), "();\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "updateTab"
        }), " = (", jsx(_components.span, {
          className: "hljs-params",
          children: "index"
        }), ") => ", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "start"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setTab"
        }), "(index));\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "useTransition"
      }), " は、保留中の Signal インジケーターとトランジションを開始するメソッドを返します。このメソッドは、更新の際に使用します。"]
    }), "\n", jsx(_components.p, {
      children: "この保留中の Signal を使って、UI にインジケーターを表示する必要があります。タブコンテナの div に pending クラスを追加しましょう:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: ["<div ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "class"
        }), "=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"tab\""
        }), " classList={{ ", jsx(_components.span, {
          className: "hljs-attr",
          children: "pending"
        }), ": ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "pending"
        }), "() }}>\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "これで、タブの切り替えがよりスムーズになるはずです。"
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
