import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [{
  "depth": 1,
  "value": "TypeScript",
  "children": [{
    "depth": 2,
    "value": "Configuring TypeScript",
    "children": []
  }, {
    "depth": 2,
    "value": "API Types",
    "children": [{
      "depth": 3,
      "value": "Signals",
      "children": [{
        "depth": 5,
        "value": "Defaults",
        "children": []
      }]
    }, {
      "depth": 3,
      "value": "Context",
      "children": []
    }]
  }, {
    "depth": 2,
    "value": "Component Types",
    "children": []
  }, {
    "depth": 2,
    "value": "Event Handlers",
    "children": []
  }, {
    "depth": 2,
    "value": "The ref Attribute",
    "children": []
  }, {
    "depth": 2,
    "value": "Control Flow Narrowing",
    "children": []
  }, {
    "depth": 2,
    "value": "Special JSX Attributes and Directives",
    "children": [{
      "depth": 3,
      "value": "on:___/oncapture:___",
      "children": []
    }, {
      "depth": 3,
      "value": "prop:___/attr:___",
      "children": []
    }, {
      "depth": 3,
      "value": "use:___",
      "children": []
    }]
  }]
}];
function _createMdxContent(props) {
  const _components = Object.assign({
    h1: "h1",
    a: "a",
    p: "p",
    h2: "h2",
    code: "code",
    pre: "pre",
    span: "span",
    h3: "h3",
    h5: "h5",
    ol: "ol",
    li: "li"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.h1, {
      id: "typescript",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#typescript",
        children: "#"
      }), "TypeScript"]
    }), "\n", jsx(_components.p, {
      children: "Solid is designed to be easy to use with TypeScript:\nits use of standard JSX makes code largely understood by TypeScript,\nand it provides sophisticated built-in types for its API.\nThis guide covers some useful tips for working with TypeScript and\ntyping your Solid code."
    }), "\n", jsxs(_components.h2, {
      id: "configuring-typescript",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#configuring-typescript",
        children: "#"
      }), "Configuring TypeScript"]
    }), "\n", jsxs(_components.p, {
      children: ["The ", jsx(_components.a, {
        href: "https://github.com/solidjs/templates/",
        children: "Solid starter templates"
      }), "\noffer good starting points for\n", jsx(_components.a, {
        href: "https://github.com/solidjs/templates/blob/master/ts/tsconfig.json",
        children: jsx(_components.code, {
          children: "tsconfig.json"
        })
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["Most importantly, to use TypeScript with the Solid JSX compiler,\nyou need to configure TypeScript to leave JSX constructs alone via\n", jsx(_components.a, {
        href: "https://www.typescriptlang.org/tsconfig#jsx",
        children: jsx(_components.code, {
          children: "\"jsx\": \"preserve\""
        })
      }), ",\nand tell TypeScript where the JSX types come from via\n", jsx(_components.a, {
        href: "https://www.typescriptlang.org/tsconfig#jsxImportSource",
        children: jsx(_components.code, {
          children: "\"jsxImportSource\": \"solid-js\""
        })
      }), ".\nSo, a minimal ", jsx(_components.code, {
        children: "tsconfig.json"
      }), " would look like this:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-json",
        children: [jsx(_components.span, {
          className: "hljs-punctuation",
          children: "{"
        }), "\n  ", jsx(_components.span, {
          className: "hljs-attr",
          children: "\"compilerOptions\""
        }), jsx(_components.span, {
          className: "hljs-punctuation",
          children: ":"
        }), " ", jsx(_components.span, {
          className: "hljs-punctuation",
          children: "{"
        }), "\n    ", jsx(_components.span, {
          className: "hljs-attr",
          children: "\"jsx\""
        }), jsx(_components.span, {
          className: "hljs-punctuation",
          children: ":"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"preserve\""
        }), jsx(_components.span, {
          className: "hljs-punctuation",
          children: ","
        }), "\n    ", jsx(_components.span, {
          className: "hljs-attr",
          children: "\"jsxImportSource\""
        }), jsx(_components.span, {
          className: "hljs-punctuation",
          children: ":"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"solid-js\""
        }), "\n  ", jsx(_components.span, {
          className: "hljs-punctuation",
          children: "}"
        }), "\n", jsx(_components.span, {
          className: "hljs-punctuation",
          children: "}"
        }), "\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["If your code base uses a mix of JSX types (e.g., some files are React\nwhile other files are Solid), you can set the default ", jsx(_components.code, {
        children: "jsxImportSource"
      }), "\nin ", jsx(_components.code, {
        children: "tsconfig.json"
      }), " for the majority of your code, and then\n", jsxs(_components.a, {
        href: "https://www.typescriptlang.org/tsconfig#jsxImportSource",
        children: ["override the ", jsx(_components.code, {
          children: "jsxImportSource"
        }), " option"]
      }), "\nin specific ", jsx(_components.code, {
        children: ".tsx"
      }), " files using the following pragma:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsxs(_components.span, {
          className: "hljs-comment",
          children: ["/** ", jsx(_components.span, {
            className: "hljs-doctag",
            children: "@jsxImportSource"
          }), " ", jsx(_components.span, {
            className: "hljs-variable",
            children: "solid"
          }), "-js */"]
        }), "\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "or"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsxs(_components.span, {
          className: "hljs-comment",
          children: ["/** ", jsx(_components.span, {
            className: "hljs-doctag",
            children: "@jsxImportSource"
          }), " react */"]
        }), "\n"]
      })
    }), "\n", jsxs(_components.h2, {
      id: "api-types",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#api-types",
        children: "#"
      }), "API Types"]
    }), "\n", jsxs(_components.p, {
      children: ["Solid is written in TypeScript, so everything is typed out of the box.\nThe ", jsx(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api",
        children: "API documentation"
      }), " details the\ntypes for all API calls, as well as several helpful type definitions to make it\neasier to refer to Solid notions when you need to specify explicit types.\nHere, we explore the resulting types when using a few core primitives."]
    }), "\n", jsxs(_components.h3, {
      id: "signals",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#signals",
        children: "#"
      }), "Signals"]
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "createSignal<T>"
      }), " is parameterized by the type ", jsx(_components.code, {
        children: "T"
      }), " of the object stored in the\nsignal.  For example:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = createSignal<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), ">();\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["The first ", jsx(_components.code, {
        children: "createSignal"
      }), " has return type ", jsx(_components.code, {
        children: "Signal<number>"
      }), ", corresponding to\nthe type we passed to it. This is a tuple of the getter and\nsetter, which each have a generic type:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " { ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Signal"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Accessor"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Setter"
        }), " } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Signal"
        }), "<T> = [", jsx(_components.span, {
          className: "hljs-attr",
          children: "get"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Accessor"
        }), "<T>, ", jsx(_components.span, {
          className: "hljs-attr",
          children: "set"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Setter"
        }), "<T>];\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In this case, the signal getter ", jsx(_components.code, {
        children: "count"
      }), " has type\n", jsx(_components.code, {
        children: "Accessor<number | undefined>"
      }), ". ", jsx(_components.code, {
        children: "Accessor<T>"
      }), " is a type definition\nprovided by Solid, in this case equivalent to ", jsx(_components.code, {
        children: "() => number | undefined"
      }), ".\nThe ", jsx(_components.code, {
        children: "| undefined"
      }), " gets added in this example because we did not provide a\ndefault value to ", jsx(_components.code, {
        children: "createSignal"
      }), ", so the signal value indeed starts out as\n", jsx(_components.code, {
        children: "undefined"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["The signal setter ", jsx(_components.code, {
        children: "setCount"
      }), " has type ", jsx(_components.code, {
        children: "Setter<number>"
      }), ", which is a more\ncomplicated type definition corresponding roughly to\n", jsx(_components.code, {
        children: "(value?: number | ((prev?: number) => number)) => number"
      }), ", representing the\ntwo possibilities for the passed argument: you can call ", jsx(_components.code, {
        children: "setCount"
      }), " with\neither a ", jsx(_components.code, {
        children: "number"
      }), " or a\nfunction taking the previous value (if there was one) and returning a ", jsx(_components.code, {
        children: "number"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["The actual ", jsx(_components.code, {
        children: "Setter"
      }), " type is more complicated, to detect accidentally passing\na function to the setter when you might have wanted to set the signal to that\nfunction value instead of calling the function to determine the new value.\nIf you're getting a TypeScript error \"Argument ... is not assignable to\nparameter\" when calling ", jsx(_components.code, {
        children: "setCount(value)"
      }), ", then try wrapping the setter\nargument as in ", jsx(_components.code, {
        children: "setCount(() => value)"
      }), " to make sure that ", jsx(_components.code, {
        children: "value"
      }), " isn't called."]
    }), "\n", jsxs(_components.h5, {
      id: "defaults",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#defaults",
        children: "#"
      }), "Defaults"]
    }), "\n", jsxs(_components.p, {
      children: ["We can avoid having to explicitly provide the type of the signal when calling\n", jsx(_components.code, {
        children: "createSignal"
      }), ", and avoid the ", jsx(_components.code, {
        children: "| undefined"
      }), " part of the type, by providing\na default value to ", jsx(_components.code, {
        children: "createSignal"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [name, setName] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "''"
        }), ");\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In this case, TypeScript infers that the signal types are ", jsx(_components.code, {
        children: "number"
      }), " and ", jsx(_components.code, {
        children: "string"
      }), "\nrespectively.  Thus, for example, ", jsx(_components.code, {
        children: "count"
      }), " obtains type ", jsx(_components.code, {
        children: "Accessor<number>"
      }), "\nand ", jsx(_components.code, {
        children: "name"
      }), " obtains type ", jsx(_components.code, {
        children: "Accessor<string>"
      }), " (without ", jsx(_components.code, {
        children: "| undefined"
      }), ")."]
    }), "\n", jsxs(_components.h3, {
      id: "context",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#context",
        children: "#"
      }), "Context"]
    }), "\n", jsxs(_components.p, {
      children: ["Similar to signals,\n", jsx(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#createcontext",
        children: jsx(_components.code, {
          children: "createContext<T>"
        })
      }), "\nis parameterized by the type ", jsx(_components.code, {
        children: "T"
      }), " of the context value.\nWe can provide this type explicitly:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Data"
        }), " = {", jsx(_components.span, {
          className: "hljs-attr",
          children: "count"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), ", ", jsx(_components.span, {
          className: "hljs-attr",
          children: "name"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), "};\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " dataContext = createContext<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Data"
        }), ">();\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In this case, ", jsx(_components.code, {
        children: "dataContext"
      }), " has type ", jsx(_components.code, {
        children: "Context<Data | undefined>"
      }), ",\ncausing ", jsx(_components.code, {
        children: "useContext(dataContext)"
      }), " to have matching return type ", jsx(_components.code, {
        children: "Data |  undefined"
      }), ".\nThe reason for ", jsx(_components.code, {
        children: "| undefined"
      }), " is that the context might not be provided in the\nancestors of the current component, in which case ", jsx(_components.code, {
        children: "useContext"
      }), " returns\n", jsx(_components.code, {
        children: "undefined"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["If we instead provide a default value to ", jsx(_components.code, {
        children: "createContext"
      }), ", we avoid the\n", jsx(_components.code, {
        children: "| undefined"
      }), " part of the type, and often avoid having to explicitly specify\nthe type of the ", jsx(_components.code, {
        children: "createContext"
      }), " as well:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " dataContext = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createContext"
        }), "({", jsx(_components.span, {
          className: "hljs-attr",
          children: "count"
        }), ": ", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ", ", jsx(_components.span, {
          className: "hljs-attr",
          children: "name"
        }), ": ", jsx(_components.span, {
          className: "hljs-string",
          children: "''"
        }), "});\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In this case, TypeScript infers that ", jsx(_components.code, {
        children: "dataContext"
      }), " has type\n", jsx(_components.code, {
        children: "Context<{count: number, name: string}>"
      }), ", which is equivalent to\n", jsx(_components.code, {
        children: "Context<Data>"
      }), " (without ", jsx(_components.code, {
        children: "| undefined"
      }), ")."]
    }), "\n", jsxs(_components.p, {
      children: ["Another common pattern is to define a factory function that produces the\nvalue for a context.  Then we can grab the return type of that function using\nTypeScript's\n", jsx(_components.a, {
        href: "https://www.typescriptlang.org/docs/handbook/utility-types.html#returntypetype",
        children: jsx(_components.code, {
          children: "ReturnType"
        })
      }), "\ntype helper, and use that to type the context:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "makeCountNameContext"
        }), " = (", jsxs(_components.span, {
          className: "hljs-params",
          children: ["initialCount = ", jsx(_components.span, {
            className: "hljs-number",
            children: "0"
          }), ", initialName = ", jsx(_components.span, {
            className: "hljs-string",
            children: "''"
          })]
        }), ") => {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(initialCount);\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [name, setName] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(initialName);\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " [{count, name}, {setCount, setName}] ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "as"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), ";\n    ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// `as const` forces tuple type inference"
        }), "\n};\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CountNameContextType"
        }), " = ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ReturnType"
        }), "<", jsx(_components.span, {
          className: "hljs-keyword",
          children: "typeof"
        }), " makeCountNameContext>;\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CountNameContext"
        }), " = createContext<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CountNameContextType"
        }), ">();\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useCountNameContext"
        }), " = (", jsx(_components.span, {
          className: "hljs-params"
        }), ") => ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useContext"
        }), "(", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CountNameContext"
        }), ");\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In this example, ", jsx(_components.code, {
        children: "CountNameContextType"
      }), " corresponds to the return value of\n", jsx(_components.code, {
        children: "makeCountNameContext"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: ["[\n  {", jsx(_components.span, {
          className: "hljs-keyword",
          children: "readonly"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "count"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Accessor"
        }), "<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), ">, ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "readonly"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "name"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Accessor"
        }), "<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), ">},\n  {", jsx(_components.span, {
          className: "hljs-keyword",
          children: "readonly"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "setCount"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Setter"
        }), "<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), ">, ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "readonly"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "setName"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Setter"
        }), "<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), ">}\n]\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["and ", jsx(_components.code, {
        children: "useCountNameContext"
      }), " has type ", jsx(_components.code, {
        children: "() => CountNameContextType | undefined"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["If you want to avoid the ", jsx(_components.code, {
        children: "undefined"
      }), " possibility, you could assert that the\ncontext is always provided when used:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useCountNameContext"
        }), " = (", jsx(_components.span, {
          className: "hljs-params"
        }), ") => ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useContext"
        }), "(", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CountNameContext"
        }), ")!;\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["This is a dangerous assumption; it would be safer to actually provide a\ndefault argument to ", jsx(_components.code, {
        children: "createContext"
      }), " so that the context is always\ndefined."]
    }), "\n", jsxs(_components.h2, {
      id: "component-types",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#component-types",
        children: "#"
      }), "Component Types"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " { ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), " } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), "<P = {}> = ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "props: P"
          }), ") =>"]
        }), " ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "Element"
        }), ";\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["To type a basic component function, use the ", jsx(_components.code, {
        children: "Component<P>"
      }), " type,\nwhere ", jsx(_components.code, {
        children: "P"
      }), " is the type of the ", jsx(_components.code, {
        children: "props"
      }), " argument and should be an ", jsx(_components.a, {
        href: "https://www.typescriptlang.org/docs/handbook/2/objects.html",
        children: "object type"
      }), ".\nThis will enforce that correctly typed props get passed in as attributes,\nand that the return value is something that can be rendered by Solid:\na ", jsx(_components.code, {
        children: "JSX.Element"
      }), " can be a DOM node, an array of ", jsx(_components.code, {
        children: "JSX.Element"
      }), "s,\na function returning a ", jsx(_components.code, {
        children: "JSX.Element"
      }), ", a boolean, ", jsx(_components.code, {
        children: "undefined"
      }), "/", jsx(_components.code, {
        children: "null"
      }), ", etc.\nHere are some examples:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Counter"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), " = ", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n    ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{()"
            }), " =>"]
          }), " setCount((c) => c+1)}>\n      {count()}\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n  );\n};\n\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Counter"
            }), "/>"]
          })
        }), ";              ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// good"
        }), "\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Counter"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "initial"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{5}/"
            }), ">"]
          })
        }), ";  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// type error: no initial prop"
        }), "\n", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Counter"
            }), ">"]
          }), "hi", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Counter"
            }), ">"]
          })]
        }), "    ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// type error: no children prop"
        }), "\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "InitCounter"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), "<{", jsx(_components.span, {
          className: "hljs-attr",
          children: "initial"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), "}> = ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "props"
          }), ") =>"]
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(props.", jsx(_components.span, {
          className: "hljs-property",
          children: "initial"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n    ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{()"
            }), " =>"]
          }), " setCount((c) => c+1)}>\n      {count()}\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n  );\n};\n\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "InitCounter"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "initial"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{5}/"
            }), ">"]
          })
        }), ";  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// good"
        }), "\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["If you want your component to take JSX children, you can either explicitly\nadd a type for ", jsx(_components.code, {
        children: "children"
      }), " to ", jsx(_components.code, {
        children: "P"
      }), ", or you can use the ", jsx(_components.code, {
        children: "ParentComponent"
      }), " type\nwhich automatically adds ", jsx(_components.code, {
        children: "children?: JSX.Element"
      }), ".  Alternatively, if you'd\nlike to declare your component with ", jsx(_components.code, {
        children: "function"
      }), " instead of ", jsx(_components.code, {
        children: "const"
      }), ", you can\nuse the ", jsx(_components.code, {
        children: "ParentProps"
      }), " helper to type ", jsx(_components.code, {
        children: "props"
      }), ".  Some examples:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " { ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentComponent"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentProps"
        }), " } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentProps"
        }), "<P = {}> = P & { children?: ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "Element"
        }), " };\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentComponent"
        }), "<P = {}> = ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), "<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentProps"
        }), "<P>>;\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// Equivalent typings:"
        }), "\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "//const CustomCounter: Component<{children?: JSX.Element}> = ..."
        }), "\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "//function CustomCounter(props: ParentProps): JSX.Element { ..."
        }), "\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CustomCounter"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentComponent"
        }), " = ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "props"
          }), ") =>"]
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n    ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{()"
            }), " =>"]
          }), " setCount((c) => c+1)}>\n      {count()}\n      {props.children}\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n  );\n};\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// Equivalent typings:"
        }), "\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "//const CustomInitCounter: Component<{initial: number, children?: JSX.Element}> = ..."
        }), "\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "//function CustomInitCounter(props: ParentProps<{initial: number}>): JSX.Element { ..."
        }), "\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CustomInitCounter"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ParentComponent"
        }), "<{", jsx(_components.span, {
          className: "hljs-attr",
          children: "initial"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), "}> = ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "props"
          }), ") =>"]
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(props.", jsx(_components.span, {
          className: "hljs-property",
          children: "initial"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n    ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{()"
            }), " =>"]
          }), " setCount((c) => c+1)}>\n      {count()}\n      {props.children}\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n  );\n};\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In the latter example, the ", jsx(_components.code, {
        children: "props"
      }), " parameter automatically gets typed as\n", jsx(_components.code, {
        children: "props: ParentProps<{initial: number}>"
      }), " which is equivalent to\n", jsx(_components.code, {
        children: "props: {initial: number, children?: JSX.Element}"
      }), ".\n(Note that, before Solid 1.4, ", jsx(_components.code, {
        children: "Component"
      }), " was equivalent to ", jsx(_components.code, {
        children: "ParentComponent"
      }), ".)"]
    }), "\n", jsxs(_components.p, {
      children: ["Solid provides two other ", jsx(_components.code, {
        children: "Component"
      }), " subtypes for dealing with ", jsx(_components.code, {
        children: "children"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-ts",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " {", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "FlowComponent"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "FlowProps"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "VoidComponent"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "VoidProps"
        }), "} ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "FlowProps"
        }), "<P = {}, C = ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "Element"
        }), "> = P & { ", jsx(_components.span, {
          className: "hljs-attr",
          children: "children"
        }), ": C };\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "FlowComponent"
        }), "<P = {}, C = ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "Element"
        }), "> = ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), "<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "FlowProps"
        }), "<P, C>>;\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "VoidProps"
        }), "<P = {}> = P & { children?: ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "never"
        }), " };\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "VoidComponent"
        }), "<P = {}> = ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Component"
        }), "<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "VoidProps"
        }), "<P>>;\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "VoidComponent"
      }), " is for components that definitely do not support ", jsx(_components.code, {
        children: "children"
      }), ".\n", jsx(_components.code, {
        children: "VoidComponent<P>"
      }), " is equivalent to ", jsx(_components.code, {
        children: "Component<P>"
      }), " when ", jsx(_components.code, {
        children: "P"
      }), " doesn't provide\na type for ", jsx(_components.code, {
        children: "children"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "FlowComponent"
      }), " is intended for \"control flow\" components like Solid's\n", jsx(_components.code, {
        children: "<Show>"
      }), " and ", jsx(_components.code, {
        children: "<For>"
      }), ".  Such components generally require ", jsx(_components.code, {
        children: "children"
      }), " to make\nsense, and sometimes have specific types for ", jsx(_components.code, {
        children: "children"
      }), ", such as requiring it\nto be a single function.  For example:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CallMeMaybe"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "FlowComponent"
        }), "<{", jsx(_components.span, {
          className: "hljs-attr",
          children: "when"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "boolean"
        }), "}, ", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "void"
        }), "> = ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "props"
          }), ") =>"]
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createEffect"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n    ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "if"
        }), " (props.", jsx(_components.span, {
          className: "hljs-property",
          children: "when"
        }), ")\n      props.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "children"
        }), "();\n  });\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsx(_components.span, {
            className: "hljs-tag",
            children: "<>"
          }), "{props.when ? 'Calling' : 'Not Calling'}", jsx(_components.span, {
            className: "hljs-tag",
            children: "</>"
          })]
        }), ";\n};\n\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "CallMeMaybe"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{true}/"
            }), ">"]
          })
        }), ";  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// type error: missing children"
        }), "\n", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "CallMeMaybe"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{true}"
            }), ">"]
          }), "hi", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "CallMeMaybe"
            }), ">"]
          })]
        }), ";  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// type error: children"
        }), "\n", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "CallMeMaybe"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{true}"
            }), ">"]
          }), "\n  {() => console.log(\"Here's my number\")}\n", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "CallMeMaybe"
            }), ">"]
          })]
        }), ";              ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// good"
        }), "\n"]
      })
    }), "\n", jsxs(_components.h2, {
      id: "event-handlers",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#event-handlers",
        children: "#"
      }), "Event Handlers"]
    }), "\n", jsxs(_components.p, {
      children: ["The namespace ", jsx(_components.code, {
        children: "JSX"
      }), " offers a suite of useful types for working with HTML DOM\nin particular.  See the\n", jsx(_components.a, {
        href: "https://github.com/ryansolid/dom-expressions/blob/main/packages/dom-expressions/src/jsx.d.ts",
        children: "definition of JSX in dom-expressions"
      }), "\nfor all the types provided."]
    }), "\n", jsxs(_components.p, {
      children: ["One useful helper type provided by the ", jsx(_components.code, {
        children: "JSX"
      }), " namespace is\n", jsx(_components.code, {
        children: "JSX.EventHandler<T, E>"
      }), ",\nwhich represents a single-argument event handler for a DOM element type ", jsx(_components.code, {
        children: "T"
      }), "\nand event type ", jsx(_components.code, {
        children: "E"
      }), ".\nYou can use this to type any event handlers you define outside JSX.\nFor example:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "type"
        }), " { ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), " } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "onInput"
        }), ": ", jsx(_components.span, {
          className: "hljs-variable constant_",
          children: "JSX"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "EventHandler"
        }), "<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "HTMLInputElement"
        }), ", ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "InputEvent"
        }), "> = ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "event"
          }), ") =>"]
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "'input changed to'"
        }), ", event.", jsx(_components.span, {
          className: "hljs-property",
          children: "currentTarget"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "value"
        }), ");\n};\n\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "input"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onInput"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{onInput}/"
            }), ">"]
          })
        }), "\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Handlers defined inline within\n", jsxs(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#on___",
        children: [jsx(_components.code, {
          children: "on___"
        }), " JSX attributes"]
      }), "\n(with built-in event types) are automatically typed as the appropriate\n", jsx(_components.code, {
        children: "JSX.EventHandler"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: ["<input onInput={", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "event"
          }), ") =>"]
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "'input changed to'"
        }), ", event.", jsx(_components.span, {
          className: "hljs-property",
          children: "currentTarget"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "value"
        }), ");\n}}/>;\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Note that ", jsx(_components.code, {
        children: "JSX.EventHandler<T>"
      }), " constrains the event's\n", jsxs(_components.a, {
        href: "https://developer.mozilla.org/en-US/docs/Web/API/Event/currentTarget",
        children: [jsx(_components.code, {
          children: "currentTarget"
        }), " attribute"]
      }), "\nto be of type ", jsx(_components.code, {
        children: "T"
      }), " (in the example, ", jsx(_components.code, {
        children: "event.currentTarget"
      }), " is typed\nas ", jsx(_components.code, {
        children: "HTMLInputEvent"
      }), ", so has attribute ", jsx(_components.code, {
        children: "value"
      }), ").  However, the event's\n", jsxs(_components.a, {
        href: "https://developer.mozilla.org/en-US/docs/Web/API/Event/target",
        children: [jsx(_components.code, {
          children: "target"
        }), " attribute"]
      }), "\ncould be any ", jsx(_components.code, {
        children: "DOMElement"
      }), ".\nThis is because ", jsx(_components.code, {
        children: "currentTarget"
      }), " is the element that the\nevent handler was attached to, so has a known type, whereas ", jsx(_components.code, {
        children: "target"
      }), " is\nwhatever the user interacted with that caused the event to bubble to or get\ncaptured by the event handler, which can be any DOM element."]
    }), "\n", jsxs(_components.h2, {
      id: "the-ref-attribute",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#the-ref-attribute",
        children: "#"
      }), "The ref Attribute"]
    }), "\n", jsxs(_components.p, {
      children: ["When we use the ", jsx(_components.code, {
        children: "ref"
      }), " attribute with a variable, we tell Solid to assign the\nDOM element to\nthe variable once the element is rendered. Without TypeScript, this looks like:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "let"
        }), " divRef;\n\n", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(divRef); ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// undefined"
        }), "\n\n", jsx(_components.span, {
          className: "hljs-title function_",
          children: "onMount"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(divRef); ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// <div> element"
        }), "\n})\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "ref"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{divRef}/"
            }), ">"]
          })
        }), "\n)\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["This presents a challenge for typing that variable: should we type ", jsx(_components.code, {
        children: "divRef"
      }), "\nas an ", jsx(_components.code, {
        children: "HTMLDivElement"
      }), ", even though it's only set as such after rendering?\n(Here we assume TypeScript's ", jsx(_components.code, {
        children: "strictNullChecks"
      }), " mode is turned on;\notherwise, TypeScript ignores potentially ", jsx(_components.code, {
        children: "undefined"
      }), " variables.)"]
    }), "\n", jsxs(_components.p, {
      children: ["The safest pattern in TypeScript is to acknowledge that ", jsx(_components.code, {
        children: "divRef"
      }), " is ", jsx(_components.code, {
        children: "undefined"
      }), "\nfor a period of time, and check when using it:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "let"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "divRef"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "HTMLDivElement"
        }), " | ", jsx(_components.span, {
          className: "hljs-literal",
          children: "undefined"
        }), ";\n\ndivRef.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// correctly reported as an error at compile time"
        }), "\n\n", jsx(_components.span, {
          className: "hljs-title function_",
          children: "onMount"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "if"
        }), " (!divRef) ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), ";\n  divRef.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// correctly allowed"
        }), "\n});\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "ref"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{divRef!}"
            }), ">"]
          }), "\n    ...\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Alternatively, because we know ", jsx(_components.code, {
        children: "onMount"
      }), " gets called only after the ", jsx(_components.code, {
        children: "<div>"
      }), "\nelement gets rendered, we could use a\n", jsxs(_components.a, {
        href: "https://www.typescriptlang.org/docs/handbook/2/everyday-types.html#non-null-assertion-operator-postfix-",
        children: ["non-null assertion (", jsx(_components.code, {
          children: "!"
        }), ")"]
      }), "\nwhen accessing ", jsx(_components.code, {
        children: "divRef"
      }), " within ", jsx(_components.code, {
        children: "onMount"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-title function_",
          children: "onMount"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  divRef!.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();\n});\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Another fairly safe pattern is to omit ", jsx(_components.code, {
        children: "undefined"
      }), " from ", jsx(_components.code, {
        children: "divRef"
      }), "'s type,\nand use a\n", jsxs(_components.a, {
        href: "https://www.typescriptlang.org/docs/handbook/release-notes/typescript-2-7.html#definite-assignment-assertions",
        children: ["definite assignment assertion (", jsx(_components.code, {
          children: "!"
        }), ")"]
      }), "\nin the ", jsx(_components.code, {
        children: "ref"
      }), " attribute:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "let"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "divRef"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "HTMLDivElement"
        }), ";\n\ndivRef.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// correctly reported as an error at compile time"
        }), "\n\n", jsx(_components.span, {
          className: "hljs-title function_",
          children: "onMount"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  divRef.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// correctly allowed"
        }), "\n});\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "ref"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{divRef!}"
            }), ">"]
          }), "\n    ...\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["We need to use ", jsx(_components.code, {
        children: "ref={divRef!}"
      }), " because TypeScript assumes that the ", jsx(_components.code, {
        children: "ref"
      }), "\nattribute is being set to the ", jsx(_components.code, {
        children: "divRef"
      }), " variable, and thus ", jsx(_components.code, {
        children: "divRef"
      }), " should\nalready be assigned.  In Solid, it's the other way around: ", jsx(_components.code, {
        children: "divRef"
      }), " gets\nassigned to by the ", jsx(_components.code, {
        children: "ref"
      }), " attribute.  The definite assignment assertion\n", jsx(_components.code, {
        children: "divRef!"
      }), " effectively convinces TypeScript that this is what's happening:\nTypeScript will understand that ", jsx(_components.code, {
        children: "divRef"
      }), " has been assigned after this line."]
    }), "\n", jsxs(_components.p, {
      children: ["With this pattern, TypeScript will correctly flag any accidental uses of\nrefs inside the body of the function (before the JSX block where they get\ndefined).  However, TypeScript currently does not flag use of potentially\nundefined variables within nested functions.  In the context of Solid,\nyou need to take care not to use refs inside ", jsx(_components.code, {
        children: "createMemo"
      }), ", ", jsx(_components.code, {
        children: "createRenderEffect"
      }), ",\nand ", jsx(_components.code, {
        children: "createComputed"
      }), " (before the JSX block that defines the refs),\nbecause those functions are called immediately,\nso the refs won't be defined yet (yet TypeScript won't flag this as an error).\nBy contrast, the previous pattern would catch these errors."]
    }), "\n", jsx(_components.p, {
      children: "Another common, but less safe, pattern is to put the definite assignment\nassertion at the point of variable declaration."
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "let"
        }), " divRef!: ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "HTMLDivElement"
        }), ";\n\ndivRef.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// allowed despite causing an error"
        }), "\n\n", jsx(_components.span, {
          className: "hljs-title function_",
          children: "onMount"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  divRef.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "focus"
        }), "();  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// correctly allowed"
        }), "\n});\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "ref"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{divRef}"
            }), ">"]
          }), "\n    ...\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "This approach effectively turns off assignment checking for that variable,\nwhich is an easy workaround, but requires additional care.\nIn particular, unlike the previous pattern, it incorrectly allows premature\nuse of the variable, even outside nested functions."
    }), "\n", jsxs(_components.h2, {
      id: "control-flow-narrowing",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#control-flow-narrowing",
        children: "#"
      }), "Control Flow Narrowing"]
    }), "\n", jsxs(_components.p, {
      children: ["A common pattern is to use\n", jsx(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#%3Cshow%3E",
        children: jsx(_components.code, {
          children: "<Show>"
        })
      }), "\nto display data only when that data is defined:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [name, setName] = createSignal<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), ">();\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{name()}"
            }), ">"]
          }), "\n    Hello {name().replace(/\\s+/g, '\\xa0')}!\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["In this case, TypeScript can't determine that the two calls to ", jsx(_components.code, {
        children: "name()"
      }), " will\nreturn the same value, and that the second call will happen only if the first\ncall returned a truthy value.  Thus it will complain that ", jsx(_components.code, {
        children: "name()"
      }), " might be\n", jsx(_components.code, {
        children: "undefined"
      }), " when trying to call ", jsx(_components.code, {
        children: ".replace()"
      }), "."]
    }), "\n", jsx(_components.p, {
      children: "Here are two workarounds for this issue:"
    }), "\n", jsxs(_components.ol, {
      children: ["\n", jsxs(_components.li, {
        children: ["\n", jsxs(_components.p, {
          children: ["You can manually assert that ", jsx(_components.code, {
            children: "name()"
          }), " will be non-null in the second call\nusing TypeScript's\n", jsxs(_components.a, {
            href: "https://www.typescriptlang.org/docs/handbook/2/everyday-types.html#non-null-assertion-operator-postfix-",
            children: ["non-null assertion operator ", jsx(_components.code, {
              children: "!"
            })]
          }), ":"]
        }), "\n", jsx(_components.pre, {
          children: jsxs(_components.code, {
            className: "hljs language-tsx",
            children: [jsx(_components.span, {
              className: "hljs-keyword",
              children: "return"
            }), " (\n  ", jsxs(_components.span, {
              className: "xml",
              children: [jsxs(_components.span, {
                className: "hljs-tag",
                children: ["<", jsx(_components.span, {
                  className: "hljs-name",
                  children: "Show"
                }), " ", jsx(_components.span, {
                  className: "hljs-attr",
                  children: "when"
                }), "=", jsx(_components.span, {
                  className: "hljs-string",
                  children: "{name()}"
                }), ">"]
              }), "\n    Hello {name()!.replace(/\\s+/g, '\\xa0')}!\n  ", jsxs(_components.span, {
                className: "hljs-tag",
                children: ["</", jsx(_components.span, {
                  className: "hljs-name",
                  children: "Show"
                }), ">"]
              })]
            }), "\n);\n"]
          })
        }), "\n"]
      }), "\n", jsxs(_components.li, {
        children: ["\n", jsxs(_components.p, {
          children: ["You can use the callback form of ", jsx(_components.code, {
            children: "<Show>"
          }), ", which passes in the value of the\n", jsx(_components.code, {
            children: "when"
          }), " prop when it is truthy:"]
        }), "\n", jsx(_components.pre, {
          children: jsxs(_components.code, {
            className: "hljs language-tsx",
            children: [jsx(_components.span, {
              className: "hljs-keyword",
              children: "return"
            }), " (\n  ", jsxs(_components.span, {
              className: "xml",
              children: [jsxs(_components.span, {
                className: "hljs-tag",
                children: ["<", jsx(_components.span, {
                  className: "hljs-name",
                  children: "Show"
                }), " ", jsx(_components.span, {
                  className: "hljs-attr",
                  children: "when"
                }), "=", jsx(_components.span, {
                  className: "hljs-string",
                  children: "{name()}"
                }), ">"]
              }), "\n    {(n) =>\n      ", jsx(_components.span, {
                className: "hljs-tag",
                children: "<>"
              }), "Hello {n.replace(/\\s+/g, '\\xa0')}!", jsx(_components.span, {
                className: "hljs-tag",
                children: "</>"
              })]
            }), "\n    }\n  </", jsx(_components.span, {
              className: "hljs-title class_",
              children: "Show"
            }), ">\n);\n"]
          })
        }), "\n", jsxs(_components.p, {
          children: ["In this case, the typing of the ", jsx(_components.code, {
            children: "Show"
          }), " component is clever enough to tell\nTypeScript that ", jsx(_components.code, {
            children: "n"
          }), " is truthy, so it can't be ", jsx(_components.code, {
            children: "undefined"
          }), " (or ", jsx(_components.code, {
            children: "null"
          }), " or\n", jsx(_components.code, {
            children: "false"
          }), ")."]
        }), "\n", jsxs(_components.p, {
          children: ["Note, however, that this form of ", jsx(_components.code, {
            children: "<Show>"
          }), " forces the entirety of the\nchildren to render\nfrom scratch every time ", jsx(_components.code, {
            children: "name()"
          }), " changes, instead of doing this just when ", jsx(_components.code, {
            children: "name()"
          }), " changes from a falsey to a truthy value.\nThis means that the children don't have the full benefits of fine-grained\nreactivity (re-using unchanged parts and updating just what changed)."]
        }), "\n"]
      }), "\n"]
    }), "\n", jsxs(_components.h2, {
      id: "special-jsx-attributes-and-directives",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#special-jsx-attributes-and-directives",
        children: "#"
      }), "Special JSX Attributes and Directives"]
    }), "\n", jsxs(_components.h3, {
      id: "on___oncapture___",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#on___oncapture___",
        children: "#"
      }), jsx(_components.code, {
        children: "on:___"
      }), "/", jsx(_components.code, {
        children: "oncapture:___"
      })]
    }), "\n", jsxs(_components.p, {
      children: ["If you use custom event handlers via Solid's\n", jsxs(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#on%3A___%2Foncapture%3A___",
        children: [jsx(_components.code, {
          children: "on:___"
        }), "/", jsx(_components.code, {
          children: "oncapture:___"
        }), " attributes"]
      }), ",\nyou should define corresponding types for the resulting ", jsx(_components.code, {
        children: "Event"
      }), " objects\nby overriding the ", jsx(_components.code, {
        children: "CustomEvents"
      }), " and ", jsx(_components.code, {
        children: "CustomCaptureEvents"
      }), " interfaces\nwithin module ", jsx(_components.code, {
        children: "\"solid-js\""
      }), "'s ", jsx(_components.code, {
        children: "JSX"
      }), " namespace, like so:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "class"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "NameEvent"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "extends"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_ inherited__",
          children: "CustomEvent"
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-attr",
          children: "type"
        }), ": ", jsx(_components.span, {
          className: "hljs-string",
          children: "'Name'"
        }), ";\n  ", jsx(_components.span, {
          className: "hljs-attr",
          children: "detail"
        }), ": {", jsx(_components.span, {
          className: "hljs-attr",
          children: "name"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), "};\n\n  ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "constructor"
        }), "(", jsxs(_components.span, {
          className: "hljs-params",
          children: ["name: ", jsx(_components.span, {
            className: "hljs-built_in",
            children: "string"
          })]
        }), ") {\n    ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "super"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "'Name'"
        }), ", {", jsx(_components.span, {
          className: "hljs-attr",
          children: "detail"
        }), ": {name}});\n  }\n}\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "declare"
        }), " ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "module"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"solid-js\""
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "namespace"
        }), " JSX {\n    ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "interface"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CustomEvents"
        }), " { ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// on:Name"
        }), "\n      ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"Name\""
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "NameEvent"
        }), ";\n    }\n    ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "interface"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "CustomCaptureEvents"
        }), " { ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// oncapture:Name"
        }), "\n      ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"Name\""
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "NameEvent"
        }), ";\n    }\n  }\n}\n\n<div ", jsx(_components.span, {
          className: "hljs-attr",
          children: "on"
        }), ":", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Name"
        }), "={", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "event"
          }), ") =>"]
        }), " ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "'name is'"
        }), ", event.", jsx(_components.span, {
          className: "hljs-property",
          children: "detail"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "name"
        }), ")}/>\n"]
      })
    }), "\n", jsxs(_components.h3, {
      id: "prop___attr___",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#prop___attr___",
        children: "#"
      }), jsx(_components.code, {
        children: "prop:___"
      }), "/", jsx(_components.code, {
        children: "attr:___"
      })]
    }), "\n", jsxs(_components.p, {
      children: ["If you use forced properties via Solid's\n", jsxs(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#prop%3A___",
        children: [jsx(_components.code, {
          children: "prop:___"
        }), " attributes"]
      }), ",\nor custom attributes via Solid's\n", jsxs(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#attr%3A___",
        children: [jsx(_components.code, {
          children: "attr:___"
        }), " attributes"]
      }), ",\nyou can define their types in the ", jsx(_components.code, {
        children: "ExplicitProperties"
      }), " and\n", jsx(_components.code, {
        children: "ExplicitAttributes"
      }), " interfaces, respectively:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "declare"
        }), " ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "module"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"solid-js\""
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "namespace"
        }), " JSX {\n    ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "interface"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ExplicitProperties"
        }), " { ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// prop:___"
        }), "\n      ", jsx(_components.span, {
          className: "hljs-attr",
          children: "count"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), ";\n      ", jsx(_components.span, {
          className: "hljs-attr",
          children: "name"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), ";\n    }\n    ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "interface"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "ExplicitAttributes"
        }), " { ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// attr:___"
        }), "\n      ", jsx(_components.span, {
          className: "hljs-attr",
          children: "count"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "number"
        }), ";\n      ", jsx(_components.span, {
          className: "hljs-attr",
          children: "name"
        }), ": ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), ";\n    }\n  }\n}\n\n<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Input"
        }), " ", jsx(_components.span, {
          className: "hljs-attr",
          children: "prop"
        }), ":name={", jsx(_components.span, {
          className: "hljs-title function_",
          children: "name"
        }), "()} ", jsx(_components.span, {
          className: "hljs-attr",
          children: "prop"
        }), ":count={", jsx(_components.span, {
          className: "hljs-title function_",
          children: "count"
        }), "()}/>\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "my-web-component"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "attr:name"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{name()}"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "attr:count"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{count()}/"
            }), ">"]
          })
        }), "\n"]
      })
    }), "\n", jsxs(_components.h3, {
      id: "use___",
      children: [jsx(_components.a, {
        className: "header-anchor",
        href: "#use___",
        children: "#"
      }), jsx(_components.code, {
        children: "use:___"
      })]
    }), "\n", jsxs(_components.p, {
      children: ["If you define custom directives for Solid's\n", jsxs(_components.a, {
        href: "https://www.solidjs.com/docs/latest/api#use%3A___",
        children: [jsx(_components.code, {
          children: "use:___"
        }), " attributes"]
      }), ",\nyou can type them in the ", jsx(_components.code, {
        children: "Directives"
      }), " interface, like so:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-tsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "model"
        }), "(", jsxs(_components.span, {
          className: "hljs-params",
          children: ["element: HTMLInputElement, value: Accessor<Signal<", jsx(_components.span, {
            className: "hljs-built_in",
            children: "string"
          }), ">>"]
        }), ") {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [field, setField] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "value"
        }), "();\n  ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createRenderEffect"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " (element.", jsx(_components.span, {
          className: "hljs-property",
          children: "value"
        }), " = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "field"
        }), "()));\n  element.", jsx(_components.span, {
          className: "hljs-title function_",
          children: "addEventListener"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "\"input\""
        }), ", ", jsxs(_components.span, {
          className: "hljs-function",
          children: ["(", jsx(_components.span, {
            className: "hljs-params",
            children: "e"
          }), ") =>"]
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setField"
        }), "(e.", jsx(_components.span, {
          className: "hljs-property",
          children: "target"
        }), ".", jsx(_components.span, {
          className: "hljs-property",
          children: "value"
        }), "));\n}\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "declare"
        }), " ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "module"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "\"solid-js\""
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "namespace"
        }), " JSX {\n    ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "interface"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Directives"
        }), " {  ", jsx(_components.span, {
          className: "hljs-comment",
          children: "// use:model"
        }), "\n      ", jsx(_components.span, {
          className: "hljs-attr",
          children: "model"
        }), ": ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Signal"
        }), "<", jsx(_components.span, {
          className: "hljs-built_in",
          children: "string"
        }), ">;\n    }\n  }\n}\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "let"
        }), " [name, setName] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "''"
        }), ");\n\n", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "input"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "type"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"text\""
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "use:model"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{[name,"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "setName"
            }), "]} />"]
          })
        }), ";\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["If you're ", jsx(_components.code, {
        children: "import"
      }), "ing a directive ", jsx(_components.code, {
        children: "d"
      }), " from another module, and ", jsx(_components.code, {
        children: "d"
      }), " is used only\nas a directive ", jsx(_components.code, {
        children: "use:d"
      }), ", then TypeScript (or more precisely,\n", jsx(_components.a, {
        href: "https://babeljs.io/docs/en/babel-preset-typescript",
        children: jsx(_components.code, {
          children: "babel-preset-typescript"
        })
      }), ")\nwill by default remove the ", jsx(_components.code, {
        children: "import"
      }), " of ", jsx(_components.code, {
        children: "d"
      }), " (for fear that ", jsx(_components.code, {
        children: "d"
      }), " is a type,\nas TypeScript doesn't understand ", jsx(_components.code, {
        children: "use:d"
      }), " as a reference to ", jsx(_components.code, {
        children: "d"
      }), ").\nThere are two ways around this issue:"]
    }), "\n", jsxs(_components.ol, {
      children: ["\n", jsxs(_components.li, {
        children: ["\n", jsxs(_components.p, {
          children: ["Use\n", jsxs(_components.a, {
            href: "https://babeljs.io/docs/en/babel-preset-typescript#onlyremovetypeimports",
            children: [jsx(_components.code, {
              children: "babel-preset-typescript"
            }), "'s ", jsx(_components.code, {
              children: "onlyRemoveTypeImports: true"
            })]
          }), "\nconfiguration option,\nwhich prevents it from removing any ", jsx(_components.code, {
            children: "import"
          }), "s except for ", jsx(_components.code, {
            children: "import type ..."
          }), ".\nIf you're using ", jsx(_components.code, {
            children: "vite-plugin-solid"
          }), ", you can specify this option via\n", jsx(_components.code, {
            children: "solidPlugin({ typescript: { onlyRemoveTypeImports: true } })"
          }), "\nin ", jsx(_components.code, {
            children: "vite.config.ts"
          }), "."]
        }), "\n", jsxs(_components.p, {
          children: ["Note that this option can be problematic if you don't vigilantly use\n", jsx(_components.code, {
            children: "export type"
          }), " and ", jsx(_components.code, {
            children: "import type"
          }), " throughout your codebase."]
        }), "\n"]
      }), "\n", jsxs(_components.li, {
        children: ["\n", jsxs(_components.p, {
          children: ["Add a fake access like ", jsx(_components.code, {
            children: "false && d;"
          }), " to every module ", jsx(_components.code, {
            children: "import"
          }), "ing\ndirective ", jsx(_components.code, {
            children: "d"
          }), ".\nThis will stop TypeScript from removing the ", jsx(_components.code, {
            children: "import"
          }), " of ", jsx(_components.code, {
            children: "d"
          }), ", and assuming\nyou're tree-shaking via e.g. ", jsx(_components.a, {
            href: "https://terser.org/",
            children: "Terser"
          }), ",\nthis code will be omitted from your final code bundle."]
        }), "\n", jsxs(_components.p, {
          children: ["The simpler fake access ", jsx(_components.code, {
            children: "d;"
          }), " will also prevent the ", jsx(_components.code, {
            children: "import"
          }), " from being\nremoved, but will typically not be tree-shaken away, so will end up in\nyour final code bundle."]
        }), "\n"]
      }), "\n"]
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
